from .vegatradingclient import VegaTradingClient
from .vegatradingdataclient import VegaTradingDataClient
from .walletclient import WalletClient
from .generated.proto import (
    api,
    governance_pb2 as governance,
    governance_pb2_grpc as governance_grpc,
    markets_pb2 as markets,
    markets_pb2_grpc as markets_grpc,
    vega_pb2 as vega,
    vega_pb2_grpc as vega_grpc,
)

__all__ = [
    "VegaTradingClient",
    "VegaTradingDataClient",
    "WalletClient",
    "api",
    "governance",
    "governance_grpc",
    "markets",
    "markets_grpc",
    "vega",
    "vega_grpc",
]



import grpc

from .generated.proto.api import trading_pb2_grpc as trading_grpc


class VegaTradingClient(object):
    """
    The Vega Trading Client talks to a back-end node.
    """

    def __init__(self, url: str, channel=None) -> None:
        if url is None:
            raise Exception("Missing node URL")
        self.url = url

        if channel is None:
            # get a gRPC channel
            channel = grpc.insecure_channel(self.url)
            grpc.channel_ready_future(channel).result(timeout=10)

        self._trading = trading_grpc.tradingStub(channel)

    def __getattr__(self, funcname):
        return getattr(self._trading, funcname)



from google.protobuf.empty_pb2 import Empty

from .fixtures import tradingdata  # noqa: F401


def test_MarketsData(tradingdata):  # noqa: F811
    md = tradingdata.MarketsData(Empty())
    assert len(md.marketsData) > 0



from google.protobuf.empty_pb2 import Empty

import vegaapiclient as vac

from .fixtures import tradingdata  # noqa: F401


def test_MarketByID(tradingdata):  # noqa: F811
    markets = tradingdata.Markets(Empty()).markets
    assert len(markets) > 0
    marketID = markets[0].id

    req = vac.api.trading.MarketByIDRequest(marketID=marketID)
    market = tradingdata.MarketByID(req)

    assert market.market.id == markets[0].id


def test_Markets(tradingdata):  # noqa: F811
    markets = tradingdata.Markets(Empty())
    assert len(markets.markets) > 0



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/governance.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import mwitkow_goprotovalidators_validator_pb2 as github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2
from . import markets_pb2 as proto_dot_markets__pb2
from . import assets_pb2 as proto_dot_assets__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/governance.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'Z\037code.vegaprotocol.io/vega/proto',
  serialized_pb=b'\n\x16proto/governance.proto\x12\x04vega\x1a\x36github.com/mwitkow/go-proto-validators/validator.proto\x1a\x13proto/markets.proto\x1a\x12proto/assets.proto\"\xa3\x02\n\x14NetworkConfiguration\x12\x19\n\x11minCloseInSeconds\x18\x01 \x01(\x03\x12\x19\n\x11maxCloseInSeconds\x18\x02 \x01(\x03\x12\x19\n\x11minEnactInSeconds\x18\x03 \x01(\x03\x12\x19\n\x11maxEnactInSeconds\x18\x04 \x01(\x03\x12\x1d\n\x15requiredParticipation\x18\x05 \x01(\x02\x12\x18\n\x10requiredMajority\x18\x06 \x01(\x02\x12\x1a\n\x12minProposerBalance\x18\x07 \x01(\x02\x12\x17\n\x0fminVoterBalance\x18\x08 \x01(\x02\x12\x31\n\x13marginConfiguration\x18\t \x01(\x0b\x32\x14.vega.ScalingFactors\"\x0e\n\x0cUpdateMarket\"@\n\rFutureProduct\x12\x18\n\x08maturity\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x15\n\x05\x61sset\x18\x02 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"\xac\x01\n\x17InstrumentConfiguration\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x14\n\x04\x63ode\x18\x02 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x18\n\x08\x62\x61seName\x18\x03 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x19\n\tquoteName\x18\x04 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12%\n\x06\x66uture\x18\x64 \x01(\x0b\x32\x13.vega.FutureProductH\x00\x42\t\n\x07product\"\xdc\x02\n\x16NewMarketConfiguration\x12\x39\n\ninstrument\x18\x01 \x01(\x0b\x32\x1d.vega.InstrumentConfigurationB\x06\xe2\xdf\x1f\x02 \x01\x12)\n\x06simple\x18\x64 \x01(\x0b\x32\x17.vega.SimpleModelParamsH\x00\x12-\n\tlogNormal\x18\x65 \x01(\x0b\x32\x18.vega.LogNormalRiskModelH\x00\x12\x1e\n\rdecimalPlaces\x18\x03 \x01(\x04\x42\x07\xe2\xdf\x1f\x03\x18\x96\x01\x12\x10\n\x08metadata\x18\x04 \x03(\t\x12.\n\ncontinuous\x18\xc8\x01 \x01(\x0b\x32\x17.vega.ContinuousTradingH\x01\x12*\n\x08\x64iscrete\x18\xc9\x01 \x01(\x0b\x32\x15.vega.DiscreteTradingH\x01\x42\x10\n\x0eriskParametersB\r\n\x0btradingMode\"B\n\tNewMarket\x12\x35\n\x07\x63hanges\x18\x01 \x01(\x0b\x32\x1c.vega.NewMarketConfigurationB\x06\xe2\xdf\x1f\x02 \x01\"D\n\rUpdateNetwork\x12\x33\n\x07\x63hanges\x18\x01 \x01(\x0b\x32\x1a.vega.NetworkConfigurationB\x06\xe2\xdf\x1f\x02 \x01\"6\n\x08NewAsset\x12*\n\x07\x63hanges\x18\x01 \x01(\x0b\x32\x11.vega.AssetSourceB\x06\xe2\xdf\x1f\x02 \x01\"\xa0\x02\n\rProposalTerms\x12 \n\x10\x63losingTimestamp\x18\x01 \x01(\x03\x42\x06\xe2\xdf\x1f\x02\x10\x00\x12\"\n\x12\x65nactmentTimestamp\x18\x02 \x01(\x03\x42\x06\xe2\xdf\x1f\x02\x10\x00\x12\x1b\n\x13validationTimestamp\x18\x05 \x01(\x03\x12*\n\x0cupdateMarket\x18\x65 \x01(\x0b\x32\x12.vega.UpdateMarketH\x00\x12$\n\tnewMarket\x18\x66 \x01(\x0b\x32\x0f.vega.NewMarketH\x00\x12,\n\rupdateNetwork\x18g \x01(\x0b\x32\x13.vega.UpdateNetworkH\x00\x12\"\n\x08newAsset\x18h \x01(\x0b\x32\x0e.vega.NewAssetH\x00\x42\x08\n\x06\x63hange\"\xc6\x02\n\x0eGovernanceData\x12 \n\x08proposal\x18\x01 \x01(\x0b\x32\x0e.vega.Proposal\x12\x17\n\x03yes\x18\x02 \x03(\x0b\x32\n.vega.Vote\x12\x16\n\x02no\x18\x03 \x03(\x0b\x32\n.vega.Vote\x12\x34\n\x08yesParty\x18\x04 \x03(\x0b\x32\".vega.GovernanceData.YesPartyEntry\x12\x32\n\x07noParty\x18\x05 \x03(\x0b\x32!.vega.GovernanceData.NoPartyEntry\x1a;\n\rYesPartyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x19\n\x05value\x18\x02 \x01(\x0b\x32\n.vega.Vote:\x02\x38\x01\x1a:\n\x0cNoPartyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x19\n\x05value\x18\x02 \x01(\x0b\x32\n.vega.Vote:\x02\x38\x01\"\xe0\x02\n\x08Proposal\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x17\n\x07partyID\x18\x03 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12,\n\x05state\x18\x04 \x01(\x0e\x32\x14.vega.Proposal.StateB\x07\xe2\xdf\x1f\x03\x88\x01\x01\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\x12*\n\x05terms\x18\x06 \x01(\x0b\x32\x13.vega.ProposalTermsB\x06\xe2\xdf\x1f\x02 \x01\"\xae\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x10\n\x0cSTATE_FAILED\x10\x01\x12\x0e\n\nSTATE_OPEN\x10\x02\x12\x10\n\x0cSTATE_PASSED\x10\x03\x12\x12\n\x0eSTATE_REJECTED\x10\x04\x12\x12\n\x0eSTATE_DECLINED\x10\x05\x12\x11\n\rSTATE_ENACTED\x10\x06\x12\x1f\n\x1bSTATE_WAITING_FOR_NODE_VOTE\x10\x07\"\xb5\x01\n\x04Vote\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12(\n\x05value\x18\x02 \x01(\x0e\x32\x10.vega.Vote.ValueB\x07\xe2\xdf\x1f\x03\x88\x01\x01\x12\x1a\n\nproposalID\x18\x03 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\";\n\x05Value\x12\x15\n\x11VALUE_UNSPECIFIED\x10\x00\x12\x0c\n\x08VALUE_NO\x10\x01\x12\r\n\tVALUE_YES\x10\x02\x42!Z\x1f\x63ode.vegaprotocol.io/vega/protob\x06proto3'
  ,
  dependencies=[github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2.DESCRIPTOR,proto_dot_markets__pb2.DESCRIPTOR,proto_dot_assets__pb2.DESCRIPTOR,])



_PROPOSAL_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='vega.Proposal.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_FAILED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_OPEN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_PASSED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_REJECTED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_DECLINED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_ENACTED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_WAITING_FOR_NODE_VOTE', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2024,
  serialized_end=2198,
)
_sym_db.RegisterEnumDescriptor(_PROPOSAL_STATE)

_VOTE_VALUE = _descriptor.EnumDescriptor(
  name='Value',
  full_name='vega.Vote.Value',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VALUE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE_NO', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE_YES', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2323,
  serialized_end=2382,
)
_sym_db.RegisterEnumDescriptor(_VOTE_VALUE)


_NETWORKCONFIGURATION = _descriptor.Descriptor(
  name='NetworkConfiguration',
  full_name='vega.NetworkConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='minCloseInSeconds', full_name='vega.NetworkConfiguration.minCloseInSeconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxCloseInSeconds', full_name='vega.NetworkConfiguration.maxCloseInSeconds', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minEnactInSeconds', full_name='vega.NetworkConfiguration.minEnactInSeconds', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxEnactInSeconds', full_name='vega.NetworkConfiguration.maxEnactInSeconds', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requiredParticipation', full_name='vega.NetworkConfiguration.requiredParticipation', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requiredMajority', full_name='vega.NetworkConfiguration.requiredMajority', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minProposerBalance', full_name='vega.NetworkConfiguration.minProposerBalance', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minVoterBalance', full_name='vega.NetworkConfiguration.minVoterBalance', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marginConfiguration', full_name='vega.NetworkConfiguration.marginConfiguration', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=421,
)


_UPDATEMARKET = _descriptor.Descriptor(
  name='UpdateMarket',
  full_name='vega.UpdateMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=437,
)


_FUTUREPRODUCT = _descriptor.Descriptor(
  name='FutureProduct',
  full_name='vega.FutureProduct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='maturity', full_name='vega.FutureProduct.maturity', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset', full_name='vega.FutureProduct.asset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=503,
)


_INSTRUMENTCONFIGURATION = _descriptor.Descriptor(
  name='InstrumentConfiguration',
  full_name='vega.InstrumentConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='vega.InstrumentConfiguration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='vega.InstrumentConfiguration.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseName', full_name='vega.InstrumentConfiguration.baseName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quoteName', full_name='vega.InstrumentConfiguration.quoteName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='future', full_name='vega.InstrumentConfiguration.future', index=4,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='product', full_name='vega.InstrumentConfiguration.product',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=506,
  serialized_end=678,
)


_NEWMARKETCONFIGURATION = _descriptor.Descriptor(
  name='NewMarketConfiguration',
  full_name='vega.NewMarketConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instrument', full_name='vega.NewMarketConfiguration.instrument', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simple', full_name='vega.NewMarketConfiguration.simple', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logNormal', full_name='vega.NewMarketConfiguration.logNormal', index=2,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimalPlaces', full_name='vega.NewMarketConfiguration.decimalPlaces', index=3,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\003\030\226\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='vega.NewMarketConfiguration.metadata', index=4,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuous', full_name='vega.NewMarketConfiguration.continuous', index=5,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='discrete', full_name='vega.NewMarketConfiguration.discrete', index=6,
      number=201, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='riskParameters', full_name='vega.NewMarketConfiguration.riskParameters',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='tradingMode', full_name='vega.NewMarketConfiguration.tradingMode',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=681,
  serialized_end=1029,
)


_NEWMARKET = _descriptor.Descriptor(
  name='NewMarket',
  full_name='vega.NewMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='changes', full_name='vega.NewMarket.changes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1097,
)


_UPDATENETWORK = _descriptor.Descriptor(
  name='UpdateNetwork',
  full_name='vega.UpdateNetwork',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='changes', full_name='vega.UpdateNetwork.changes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1099,
  serialized_end=1167,
)


_NEWASSET = _descriptor.Descriptor(
  name='NewAsset',
  full_name='vega.NewAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='changes', full_name='vega.NewAsset.changes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1169,
  serialized_end=1223,
)


_PROPOSALTERMS = _descriptor.Descriptor(
  name='ProposalTerms',
  full_name='vega.ProposalTerms',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='closingTimestamp', full_name='vega.ProposalTerms.closingTimestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002\020\000', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enactmentTimestamp', full_name='vega.ProposalTerms.enactmentTimestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002\020\000', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validationTimestamp', full_name='vega.ProposalTerms.validationTimestamp', index=2,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updateMarket', full_name='vega.ProposalTerms.updateMarket', index=3,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newMarket', full_name='vega.ProposalTerms.newMarket', index=4,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updateNetwork', full_name='vega.ProposalTerms.updateNetwork', index=5,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newAsset', full_name='vega.ProposalTerms.newAsset', index=6,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='change', full_name='vega.ProposalTerms.change',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1226,
  serialized_end=1514,
)


_GOVERNANCEDATA_YESPARTYENTRY = _descriptor.Descriptor(
  name='YesPartyEntry',
  full_name='vega.GovernanceData.YesPartyEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='vega.GovernanceData.YesPartyEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='vega.GovernanceData.YesPartyEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1783,
)

_GOVERNANCEDATA_NOPARTYENTRY = _descriptor.Descriptor(
  name='NoPartyEntry',
  full_name='vega.GovernanceData.NoPartyEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='vega.GovernanceData.NoPartyEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='vega.GovernanceData.NoPartyEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1785,
  serialized_end=1843,
)

_GOVERNANCEDATA = _descriptor.Descriptor(
  name='GovernanceData',
  full_name='vega.GovernanceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal', full_name='vega.GovernanceData.proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yes', full_name='vega.GovernanceData.yes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no', full_name='vega.GovernanceData.no', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yesParty', full_name='vega.GovernanceData.yesParty', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noParty', full_name='vega.GovernanceData.noParty', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GOVERNANCEDATA_YESPARTYENTRY, _GOVERNANCEDATA_NOPARTYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1517,
  serialized_end=1843,
)


_PROPOSAL = _descriptor.Descriptor(
  name='Proposal',
  full_name='vega.Proposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='vega.Proposal.ID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.Proposal.reference', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.Proposal.partyID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='vega.Proposal.state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\003\210\001\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='vega.Proposal.timestamp', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='terms', full_name='vega.Proposal.terms', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROPOSAL_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1846,
  serialized_end=2198,
)


_VOTE = _descriptor.Descriptor(
  name='Vote',
  full_name='vega.Vote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.Vote.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='vega.Vote.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\003\210\001\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposalID', full_name='vega.Vote.proposalID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='vega.Vote.timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VOTE_VALUE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2201,
  serialized_end=2382,
)

_NETWORKCONFIGURATION.fields_by_name['marginConfiguration'].message_type = proto_dot_markets__pb2._SCALINGFACTORS
_INSTRUMENTCONFIGURATION.fields_by_name['future'].message_type = _FUTUREPRODUCT
_INSTRUMENTCONFIGURATION.oneofs_by_name['product'].fields.append(
  _INSTRUMENTCONFIGURATION.fields_by_name['future'])
_INSTRUMENTCONFIGURATION.fields_by_name['future'].containing_oneof = _INSTRUMENTCONFIGURATION.oneofs_by_name['product']
_NEWMARKETCONFIGURATION.fields_by_name['instrument'].message_type = _INSTRUMENTCONFIGURATION
_NEWMARKETCONFIGURATION.fields_by_name['simple'].message_type = proto_dot_markets__pb2._SIMPLEMODELPARAMS
_NEWMARKETCONFIGURATION.fields_by_name['logNormal'].message_type = proto_dot_markets__pb2._LOGNORMALRISKMODEL
_NEWMARKETCONFIGURATION.fields_by_name['continuous'].message_type = proto_dot_markets__pb2._CONTINUOUSTRADING
_NEWMARKETCONFIGURATION.fields_by_name['discrete'].message_type = proto_dot_markets__pb2._DISCRETETRADING
_NEWMARKETCONFIGURATION.oneofs_by_name['riskParameters'].fields.append(
  _NEWMARKETCONFIGURATION.fields_by_name['simple'])
_NEWMARKETCONFIGURATION.fields_by_name['simple'].containing_oneof = _NEWMARKETCONFIGURATION.oneofs_by_name['riskParameters']
_NEWMARKETCONFIGURATION.oneofs_by_name['riskParameters'].fields.append(
  _NEWMARKETCONFIGURATION.fields_by_name['logNormal'])
_NEWMARKETCONFIGURATION.fields_by_name['logNormal'].containing_oneof = _NEWMARKETCONFIGURATION.oneofs_by_name['riskParameters']
_NEWMARKETCONFIGURATION.oneofs_by_name['tradingMode'].fields.append(
  _NEWMARKETCONFIGURATION.fields_by_name['continuous'])
_NEWMARKETCONFIGURATION.fields_by_name['continuous'].containing_oneof = _NEWMARKETCONFIGURATION.oneofs_by_name['tradingMode']
_NEWMARKETCONFIGURATION.oneofs_by_name['tradingMode'].fields.append(
  _NEWMARKETCONFIGURATION.fields_by_name['discrete'])
_NEWMARKETCONFIGURATION.fields_by_name['discrete'].containing_oneof = _NEWMARKETCONFIGURATION.oneofs_by_name['tradingMode']
_NEWMARKET.fields_by_name['changes'].message_type = _NEWMARKETCONFIGURATION
_UPDATENETWORK.fields_by_name['changes'].message_type = _NETWORKCONFIGURATION
_NEWASSET.fields_by_name['changes'].message_type = proto_dot_assets__pb2._ASSETSOURCE
_PROPOSALTERMS.fields_by_name['updateMarket'].message_type = _UPDATEMARKET
_PROPOSALTERMS.fields_by_name['newMarket'].message_type = _NEWMARKET
_PROPOSALTERMS.fields_by_name['updateNetwork'].message_type = _UPDATENETWORK
_PROPOSALTERMS.fields_by_name['newAsset'].message_type = _NEWASSET
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['updateMarket'])
_PROPOSALTERMS.fields_by_name['updateMarket'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['newMarket'])
_PROPOSALTERMS.fields_by_name['newMarket'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['updateNetwork'])
_PROPOSALTERMS.fields_by_name['updateNetwork'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['newAsset'])
_PROPOSALTERMS.fields_by_name['newAsset'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_GOVERNANCEDATA_YESPARTYENTRY.fields_by_name['value'].message_type = _VOTE
_GOVERNANCEDATA_YESPARTYENTRY.containing_type = _GOVERNANCEDATA
_GOVERNANCEDATA_NOPARTYENTRY.fields_by_name['value'].message_type = _VOTE
_GOVERNANCEDATA_NOPARTYENTRY.containing_type = _GOVERNANCEDATA
_GOVERNANCEDATA.fields_by_name['proposal'].message_type = _PROPOSAL
_GOVERNANCEDATA.fields_by_name['yes'].message_type = _VOTE
_GOVERNANCEDATA.fields_by_name['no'].message_type = _VOTE
_GOVERNANCEDATA.fields_by_name['yesParty'].message_type = _GOVERNANCEDATA_YESPARTYENTRY
_GOVERNANCEDATA.fields_by_name['noParty'].message_type = _GOVERNANCEDATA_NOPARTYENTRY
_PROPOSAL.fields_by_name['state'].enum_type = _PROPOSAL_STATE
_PROPOSAL.fields_by_name['terms'].message_type = _PROPOSALTERMS
_PROPOSAL_STATE.containing_type = _PROPOSAL
_VOTE.fields_by_name['value'].enum_type = _VOTE_VALUE
_VOTE_VALUE.containing_type = _VOTE
DESCRIPTOR.message_types_by_name['NetworkConfiguration'] = _NETWORKCONFIGURATION
DESCRIPTOR.message_types_by_name['UpdateMarket'] = _UPDATEMARKET
DESCRIPTOR.message_types_by_name['FutureProduct'] = _FUTUREPRODUCT
DESCRIPTOR.message_types_by_name['InstrumentConfiguration'] = _INSTRUMENTCONFIGURATION
DESCRIPTOR.message_types_by_name['NewMarketConfiguration'] = _NEWMARKETCONFIGURATION
DESCRIPTOR.message_types_by_name['NewMarket'] = _NEWMARKET
DESCRIPTOR.message_types_by_name['UpdateNetwork'] = _UPDATENETWORK
DESCRIPTOR.message_types_by_name['NewAsset'] = _NEWASSET
DESCRIPTOR.message_types_by_name['ProposalTerms'] = _PROPOSALTERMS
DESCRIPTOR.message_types_by_name['GovernanceData'] = _GOVERNANCEDATA
DESCRIPTOR.message_types_by_name['Proposal'] = _PROPOSAL
DESCRIPTOR.message_types_by_name['Vote'] = _VOTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NetworkConfiguration = _reflection.GeneratedProtocolMessageType('NetworkConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKCONFIGURATION,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.NetworkConfiguration)
  })
_sym_db.RegisterMessage(NetworkConfiguration)

UpdateMarket = _reflection.GeneratedProtocolMessageType('UpdateMarket', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMARKET,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.UpdateMarket)
  })
_sym_db.RegisterMessage(UpdateMarket)

FutureProduct = _reflection.GeneratedProtocolMessageType('FutureProduct', (_message.Message,), {
  'DESCRIPTOR' : _FUTUREPRODUCT,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.FutureProduct)
  })
_sym_db.RegisterMessage(FutureProduct)

InstrumentConfiguration = _reflection.GeneratedProtocolMessageType('InstrumentConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _INSTRUMENTCONFIGURATION,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.InstrumentConfiguration)
  })
_sym_db.RegisterMessage(InstrumentConfiguration)

NewMarketConfiguration = _reflection.GeneratedProtocolMessageType('NewMarketConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _NEWMARKETCONFIGURATION,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.NewMarketConfiguration)
  })
_sym_db.RegisterMessage(NewMarketConfiguration)

NewMarket = _reflection.GeneratedProtocolMessageType('NewMarket', (_message.Message,), {
  'DESCRIPTOR' : _NEWMARKET,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.NewMarket)
  })
_sym_db.RegisterMessage(NewMarket)

UpdateNetwork = _reflection.GeneratedProtocolMessageType('UpdateNetwork', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENETWORK,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.UpdateNetwork)
  })
_sym_db.RegisterMessage(UpdateNetwork)

NewAsset = _reflection.GeneratedProtocolMessageType('NewAsset', (_message.Message,), {
  'DESCRIPTOR' : _NEWASSET,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.NewAsset)
  })
_sym_db.RegisterMessage(NewAsset)

ProposalTerms = _reflection.GeneratedProtocolMessageType('ProposalTerms', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSALTERMS,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.ProposalTerms)
  })
_sym_db.RegisterMessage(ProposalTerms)

GovernanceData = _reflection.GeneratedProtocolMessageType('GovernanceData', (_message.Message,), {

  'YesPartyEntry' : _reflection.GeneratedProtocolMessageType('YesPartyEntry', (_message.Message,), {
    'DESCRIPTOR' : _GOVERNANCEDATA_YESPARTYENTRY,
    '__module__' : 'proto.governance_pb2'
    # @@protoc_insertion_point(class_scope:vega.GovernanceData.YesPartyEntry)
    })
  ,

  'NoPartyEntry' : _reflection.GeneratedProtocolMessageType('NoPartyEntry', (_message.Message,), {
    'DESCRIPTOR' : _GOVERNANCEDATA_NOPARTYENTRY,
    '__module__' : 'proto.governance_pb2'
    # @@protoc_insertion_point(class_scope:vega.GovernanceData.NoPartyEntry)
    })
  ,
  'DESCRIPTOR' : _GOVERNANCEDATA,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.GovernanceData)
  })
_sym_db.RegisterMessage(GovernanceData)
_sym_db.RegisterMessage(GovernanceData.YesPartyEntry)
_sym_db.RegisterMessage(GovernanceData.NoPartyEntry)

Proposal = _reflection.GeneratedProtocolMessageType('Proposal', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSAL,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.Proposal)
  })
_sym_db.RegisterMessage(Proposal)

Vote = _reflection.GeneratedProtocolMessageType('Vote', (_message.Message,), {
  'DESCRIPTOR' : _VOTE,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.Vote)
  })
_sym_db.RegisterMessage(Vote)


DESCRIPTOR._options = None
_FUTUREPRODUCT.fields_by_name['maturity']._options = None
_FUTUREPRODUCT.fields_by_name['asset']._options = None
_INSTRUMENTCONFIGURATION.fields_by_name['name']._options = None
_INSTRUMENTCONFIGURATION.fields_by_name['code']._options = None
_INSTRUMENTCONFIGURATION.fields_by_name['baseName']._options = None
_INSTRUMENTCONFIGURATION.fields_by_name['quoteName']._options = None
_NEWMARKETCONFIGURATION.fields_by_name['instrument']._options = None
_NEWMARKETCONFIGURATION.fields_by_name['decimalPlaces']._options = None
_NEWMARKET.fields_by_name['changes']._options = None
_UPDATENETWORK.fields_by_name['changes']._options = None
_NEWASSET.fields_by_name['changes']._options = None
_PROPOSALTERMS.fields_by_name['closingTimestamp']._options = None
_PROPOSALTERMS.fields_by_name['enactmentTimestamp']._options = None
_GOVERNANCEDATA_YESPARTYENTRY._options = None
_GOVERNANCEDATA_NOPARTYENTRY._options = None
_PROPOSAL.fields_by_name['partyID']._options = None
_PROPOSAL.fields_by_name['state']._options = None
_PROPOSAL.fields_by_name['terms']._options = None
_VOTE.fields_by_name['partyID']._options = None
_VOTE.fields_by_name['value']._options = None
_VOTE.fields_by_name['proposalID']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/chain_events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import assets_pb2 as proto_dot_assets__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/chain_events.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'Z\037code.vegaprotocol.io/vega/proto',
  serialized_pb=b'\n\x18proto/chain_events.proto\x12\x04vega\x1a\x12proto/assets.proto\"K\n\x13\x42uiltinAssetDeposit\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x0f\n\x07partyID\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04\"N\n\x16\x42uiltinAssetWithdrawal\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x0f\n\x07partyID\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04\"\x81\x01\n\x11\x42uiltinAssetEvent\x12-\n\x07\x64\x65posit\x18\xe9\x07 \x01(\x0b\x32\x19.vega.BuiltinAssetDepositH\x00\x12\x33\n\nwithdrawal\x18\xea\x07 \x01(\x0b\x32\x1c.vega.BuiltinAssetWithdrawalH\x00\x42\x08\n\x06\x61\x63tion\"%\n\x0e\x45RC20AssetList\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\"\'\n\x10\x45RC20AssetDelist\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\"Y\n\x0c\x45RC20Deposit\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x1d\n\x15sourceEthereumAddress\x18\x02 \x01(\t\x12\x15\n\rtargetPartyID\x18\x03 \x01(\t\"t\n\x0f\x45RC20Withdrawal\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x15\n\rsourcePartyId\x18\x02 \x01(\t\x12\x1d\n\x15targetEthereumAddress\x18\x03 \x01(\t\x12\x16\n\x0ereferenceNonce\x18\x04 \x01(\t\"\xe6\x01\n\nERC20Event\x12\r\n\x05index\x18\x01 \x01(\x04\x12\r\n\x05\x62lock\x18\x02 \x01(\x04\x12*\n\tassetList\x18\xe9\x07 \x01(\x0b\x32\x14.vega.ERC20AssetListH\x00\x12.\n\x0b\x61ssetDelist\x18\xea\x07 \x01(\x0b\x32\x16.vega.ERC20AssetDelistH\x00\x12&\n\x07\x64\x65posit\x18\xeb\x07 \x01(\x0b\x32\x12.vega.ERC20DepositH\x00\x12,\n\nwithdrawal\x18\xec\x07 \x01(\x0b\x32\x15.vega.ERC20WithdrawalH\x00\x42\x08\n\x06\x61\x63tion\"R\n\nBTCDeposit\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x18\n\x10sourceBTCAddress\x18\x02 \x01(\t\x12\x15\n\rtargetPartyId\x18\x03 \x01(\t\"m\n\rBTCWithdrawal\x12\x13\n\x0bvegaAssetID\x18\x01 \x01(\t\x12\x15\n\rsourcePartyId\x18\x02 \x01(\t\x12\x18\n\x10targetBTCAddress\x18\x03 \x01(\t\x12\x16\n\x0ereferenceNonce\x18\x04 \x01(\t\"\x84\x01\n\x08\x42TCEvent\x12\r\n\x05index\x18\x01 \x01(\x04\x12\r\n\x05\x62lock\x18\x02 \x01(\x04\x12$\n\x07\x64\x65posit\x18\xe9\x07 \x01(\x0b\x32\x10.vega.BTCDepositH\x00\x12*\n\nwithdrawal\x18\xea\x07 \x01(\x0b\x32\x13.vega.BTCWithdrawalH\x00\x42\x08\n\x06\x61\x63tion\"\"\n\x0f\x45thereumAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"!\n\x0e\x42itcoinAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"|\n\nIdentifier\x12\x30\n\x0f\x65thereumAddress\x18\x01 \x01(\x0b\x32\x15.vega.EthereumAddressH\x00\x12.\n\x0e\x62itcoinAddress\x18\x02 \x01(\x0b\x32\x14.vega.BitcoinAddressH\x00\x42\x0c\n\nidentifier\",\n\x0c\x41\x64\x64Validator\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.vega.Identifier\"/\n\x0fRemoveValidator\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.vega.Identifier\"v\n\x0eValidatorEvent\x12\x10\n\x08sourceID\x18\x01 \x01(\t\x12\"\n\x03\x61\x64\x64\x18\xe9\x07 \x01(\x0b\x32\x12.vega.AddValidatorH\x00\x12$\n\x02rm\x18\xea\x07 \x01(\x0b\x32\x15.vega.RemoveValidatorH\x00\x42\x08\n\x06\x61\x63tion\"\xc0\x01\n\nChainEvent\x12\x0c\n\x04txID\x18\x01 \x01(\t\x12+\n\x07\x62uiltin\x18\xe9\x07 \x01(\x0b\x32\x17.vega.BuiltinAssetEventH\x00\x12\"\n\x05\x65rc20\x18\xea\x07 \x01(\x0b\x32\x10.vega.ERC20EventH\x00\x12\x1e\n\x03\x62tc\x18\xeb\x07 \x01(\x0b\x32\x0e.vega.BTCEventH\x00\x12*\n\tvalidator\x18\xec\x07 \x01(\x0b\x32\x14.vega.ValidatorEventH\x00\x42\x07\n\x05\x65ventB!Z\x1f\x63ode.vegaprotocol.io/vega/protob\x06proto3'
  ,
  dependencies=[proto_dot_assets__pb2.DESCRIPTOR,])




_BUILTINASSETDEPOSIT = _descriptor.Descriptor(
  name='BuiltinAssetDeposit',
  full_name='vega.BuiltinAssetDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.BuiltinAssetDeposit.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.BuiltinAssetDeposit.partyID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.BuiltinAssetDeposit.amount', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=129,
)


_BUILTINASSETWITHDRAWAL = _descriptor.Descriptor(
  name='BuiltinAssetWithdrawal',
  full_name='vega.BuiltinAssetWithdrawal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.BuiltinAssetWithdrawal.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.BuiltinAssetWithdrawal.partyID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.BuiltinAssetWithdrawal.amount', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=209,
)


_BUILTINASSETEVENT = _descriptor.Descriptor(
  name='BuiltinAssetEvent',
  full_name='vega.BuiltinAssetEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.BuiltinAssetEvent.deposit', index=0,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.BuiltinAssetEvent.withdrawal', index=1,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.BuiltinAssetEvent.action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=212,
  serialized_end=341,
)


_ERC20ASSETLIST = _descriptor.Descriptor(
  name='ERC20AssetList',
  full_name='vega.ERC20AssetList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.ERC20AssetList.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=380,
)


_ERC20ASSETDELIST = _descriptor.Descriptor(
  name='ERC20AssetDelist',
  full_name='vega.ERC20AssetDelist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.ERC20AssetDelist.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=421,
)


_ERC20DEPOSIT = _descriptor.Descriptor(
  name='ERC20Deposit',
  full_name='vega.ERC20Deposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.ERC20Deposit.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceEthereumAddress', full_name='vega.ERC20Deposit.sourceEthereumAddress', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetPartyID', full_name='vega.ERC20Deposit.targetPartyID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=512,
)


_ERC20WITHDRAWAL = _descriptor.Descriptor(
  name='ERC20Withdrawal',
  full_name='vega.ERC20Withdrawal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.ERC20Withdrawal.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourcePartyId', full_name='vega.ERC20Withdrawal.sourcePartyId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetEthereumAddress', full_name='vega.ERC20Withdrawal.targetEthereumAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referenceNonce', full_name='vega.ERC20Withdrawal.referenceNonce', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=630,
)


_ERC20EVENT = _descriptor.Descriptor(
  name='ERC20Event',
  full_name='vega.ERC20Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='vega.ERC20Event.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='vega.ERC20Event.block', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assetList', full_name='vega.ERC20Event.assetList', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assetDelist', full_name='vega.ERC20Event.assetDelist', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.ERC20Event.deposit', index=4,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.ERC20Event.withdrawal', index=5,
      number=1004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.ERC20Event.action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=633,
  serialized_end=863,
)


_BTCDEPOSIT = _descriptor.Descriptor(
  name='BTCDeposit',
  full_name='vega.BTCDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.BTCDeposit.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceBTCAddress', full_name='vega.BTCDeposit.sourceBTCAddress', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetPartyId', full_name='vega.BTCDeposit.targetPartyId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=865,
  serialized_end=947,
)


_BTCWITHDRAWAL = _descriptor.Descriptor(
  name='BTCWithdrawal',
  full_name='vega.BTCWithdrawal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vegaAssetID', full_name='vega.BTCWithdrawal.vegaAssetID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourcePartyId', full_name='vega.BTCWithdrawal.sourcePartyId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetBTCAddress', full_name='vega.BTCWithdrawal.targetBTCAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referenceNonce', full_name='vega.BTCWithdrawal.referenceNonce', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=949,
  serialized_end=1058,
)


_BTCEVENT = _descriptor.Descriptor(
  name='BTCEvent',
  full_name='vega.BTCEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='vega.BTCEvent.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='vega.BTCEvent.block', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.BTCEvent.deposit', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.BTCEvent.withdrawal', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.BTCEvent.action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1061,
  serialized_end=1193,
)


_ETHEREUMADDRESS = _descriptor.Descriptor(
  name='EthereumAddress',
  full_name='vega.EthereumAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='vega.EthereumAddress.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1195,
  serialized_end=1229,
)


_BITCOINADDRESS = _descriptor.Descriptor(
  name='BitcoinAddress',
  full_name='vega.BitcoinAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='vega.BitcoinAddress.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1264,
)


_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='vega.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ethereumAddress', full_name='vega.Identifier.ethereumAddress', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitcoinAddress', full_name='vega.Identifier.bitcoinAddress', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identifier', full_name='vega.Identifier.identifier',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1266,
  serialized_end=1390,
)


_ADDVALIDATOR = _descriptor.Descriptor(
  name='AddValidator',
  full_name='vega.AddValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.AddValidator.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1392,
  serialized_end=1436,
)


_REMOVEVALIDATOR = _descriptor.Descriptor(
  name='RemoveValidator',
  full_name='vega.RemoveValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.RemoveValidator.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1438,
  serialized_end=1485,
)


_VALIDATOREVENT = _descriptor.Descriptor(
  name='ValidatorEvent',
  full_name='vega.ValidatorEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sourceID', full_name='vega.ValidatorEvent.sourceID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='add', full_name='vega.ValidatorEvent.add', index=1,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rm', full_name='vega.ValidatorEvent.rm', index=2,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.ValidatorEvent.action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1487,
  serialized_end=1605,
)


_CHAINEVENT = _descriptor.Descriptor(
  name='ChainEvent',
  full_name='vega.ChainEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txID', full_name='vega.ChainEvent.txID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='builtin', full_name='vega.ChainEvent.builtin', index=1,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='erc20', full_name='vega.ChainEvent.erc20', index=2,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='btc', full_name='vega.ChainEvent.btc', index=3,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validator', full_name='vega.ChainEvent.validator', index=4,
      number=1004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='vega.ChainEvent.event',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1608,
  serialized_end=1800,
)

_BUILTINASSETEVENT.fields_by_name['deposit'].message_type = _BUILTINASSETDEPOSIT
_BUILTINASSETEVENT.fields_by_name['withdrawal'].message_type = _BUILTINASSETWITHDRAWAL
_BUILTINASSETEVENT.oneofs_by_name['action'].fields.append(
  _BUILTINASSETEVENT.fields_by_name['deposit'])
_BUILTINASSETEVENT.fields_by_name['deposit'].containing_oneof = _BUILTINASSETEVENT.oneofs_by_name['action']
_BUILTINASSETEVENT.oneofs_by_name['action'].fields.append(
  _BUILTINASSETEVENT.fields_by_name['withdrawal'])
_BUILTINASSETEVENT.fields_by_name['withdrawal'].containing_oneof = _BUILTINASSETEVENT.oneofs_by_name['action']
_ERC20EVENT.fields_by_name['assetList'].message_type = _ERC20ASSETLIST
_ERC20EVENT.fields_by_name['assetDelist'].message_type = _ERC20ASSETDELIST
_ERC20EVENT.fields_by_name['deposit'].message_type = _ERC20DEPOSIT
_ERC20EVENT.fields_by_name['withdrawal'].message_type = _ERC20WITHDRAWAL
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['assetList'])
_ERC20EVENT.fields_by_name['assetList'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['assetDelist'])
_ERC20EVENT.fields_by_name['assetDelist'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['deposit'])
_ERC20EVENT.fields_by_name['deposit'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['withdrawal'])
_ERC20EVENT.fields_by_name['withdrawal'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_BTCEVENT.fields_by_name['deposit'].message_type = _BTCDEPOSIT
_BTCEVENT.fields_by_name['withdrawal'].message_type = _BTCWITHDRAWAL
_BTCEVENT.oneofs_by_name['action'].fields.append(
  _BTCEVENT.fields_by_name['deposit'])
_BTCEVENT.fields_by_name['deposit'].containing_oneof = _BTCEVENT.oneofs_by_name['action']
_BTCEVENT.oneofs_by_name['action'].fields.append(
  _BTCEVENT.fields_by_name['withdrawal'])
_BTCEVENT.fields_by_name['withdrawal'].containing_oneof = _BTCEVENT.oneofs_by_name['action']
_IDENTIFIER.fields_by_name['ethereumAddress'].message_type = _ETHEREUMADDRESS
_IDENTIFIER.fields_by_name['bitcoinAddress'].message_type = _BITCOINADDRESS
_IDENTIFIER.oneofs_by_name['identifier'].fields.append(
  _IDENTIFIER.fields_by_name['ethereumAddress'])
_IDENTIFIER.fields_by_name['ethereumAddress'].containing_oneof = _IDENTIFIER.oneofs_by_name['identifier']
_IDENTIFIER.oneofs_by_name['identifier'].fields.append(
  _IDENTIFIER.fields_by_name['bitcoinAddress'])
_IDENTIFIER.fields_by_name['bitcoinAddress'].containing_oneof = _IDENTIFIER.oneofs_by_name['identifier']
_ADDVALIDATOR.fields_by_name['id'].message_type = _IDENTIFIER
_REMOVEVALIDATOR.fields_by_name['id'].message_type = _IDENTIFIER
_VALIDATOREVENT.fields_by_name['add'].message_type = _ADDVALIDATOR
_VALIDATOREVENT.fields_by_name['rm'].message_type = _REMOVEVALIDATOR
_VALIDATOREVENT.oneofs_by_name['action'].fields.append(
  _VALIDATOREVENT.fields_by_name['add'])
_VALIDATOREVENT.fields_by_name['add'].containing_oneof = _VALIDATOREVENT.oneofs_by_name['action']
_VALIDATOREVENT.oneofs_by_name['action'].fields.append(
  _VALIDATOREVENT.fields_by_name['rm'])
_VALIDATOREVENT.fields_by_name['rm'].containing_oneof = _VALIDATOREVENT.oneofs_by_name['action']
_CHAINEVENT.fields_by_name['builtin'].message_type = _BUILTINASSETEVENT
_CHAINEVENT.fields_by_name['erc20'].message_type = _ERC20EVENT
_CHAINEVENT.fields_by_name['btc'].message_type = _BTCEVENT
_CHAINEVENT.fields_by_name['validator'].message_type = _VALIDATOREVENT
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['builtin'])
_CHAINEVENT.fields_by_name['builtin'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['erc20'])
_CHAINEVENT.fields_by_name['erc20'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['btc'])
_CHAINEVENT.fields_by_name['btc'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['validator'])
_CHAINEVENT.fields_by_name['validator'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
DESCRIPTOR.message_types_by_name['BuiltinAssetDeposit'] = _BUILTINASSETDEPOSIT
DESCRIPTOR.message_types_by_name['BuiltinAssetWithdrawal'] = _BUILTINASSETWITHDRAWAL
DESCRIPTOR.message_types_by_name['BuiltinAssetEvent'] = _BUILTINASSETEVENT
DESCRIPTOR.message_types_by_name['ERC20AssetList'] = _ERC20ASSETLIST
DESCRIPTOR.message_types_by_name['ERC20AssetDelist'] = _ERC20ASSETDELIST
DESCRIPTOR.message_types_by_name['ERC20Deposit'] = _ERC20DEPOSIT
DESCRIPTOR.message_types_by_name['ERC20Withdrawal'] = _ERC20WITHDRAWAL
DESCRIPTOR.message_types_by_name['ERC20Event'] = _ERC20EVENT
DESCRIPTOR.message_types_by_name['BTCDeposit'] = _BTCDEPOSIT
DESCRIPTOR.message_types_by_name['BTCWithdrawal'] = _BTCWITHDRAWAL
DESCRIPTOR.message_types_by_name['BTCEvent'] = _BTCEVENT
DESCRIPTOR.message_types_by_name['EthereumAddress'] = _ETHEREUMADDRESS
DESCRIPTOR.message_types_by_name['BitcoinAddress'] = _BITCOINADDRESS
DESCRIPTOR.message_types_by_name['Identifier'] = _IDENTIFIER
DESCRIPTOR.message_types_by_name['AddValidator'] = _ADDVALIDATOR
DESCRIPTOR.message_types_by_name['RemoveValidator'] = _REMOVEVALIDATOR
DESCRIPTOR.message_types_by_name['ValidatorEvent'] = _VALIDATOREVENT
DESCRIPTOR.message_types_by_name['ChainEvent'] = _CHAINEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BuiltinAssetDeposit = _reflection.GeneratedProtocolMessageType('BuiltinAssetDeposit', (_message.Message,), {
  'DESCRIPTOR' : _BUILTINASSETDEPOSIT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BuiltinAssetDeposit)
  })
_sym_db.RegisterMessage(BuiltinAssetDeposit)

BuiltinAssetWithdrawal = _reflection.GeneratedProtocolMessageType('BuiltinAssetWithdrawal', (_message.Message,), {
  'DESCRIPTOR' : _BUILTINASSETWITHDRAWAL,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BuiltinAssetWithdrawal)
  })
_sym_db.RegisterMessage(BuiltinAssetWithdrawal)

BuiltinAssetEvent = _reflection.GeneratedProtocolMessageType('BuiltinAssetEvent', (_message.Message,), {
  'DESCRIPTOR' : _BUILTINASSETEVENT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BuiltinAssetEvent)
  })
_sym_db.RegisterMessage(BuiltinAssetEvent)

ERC20AssetList = _reflection.GeneratedProtocolMessageType('ERC20AssetList', (_message.Message,), {
  'DESCRIPTOR' : _ERC20ASSETLIST,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20AssetList)
  })
_sym_db.RegisterMessage(ERC20AssetList)

ERC20AssetDelist = _reflection.GeneratedProtocolMessageType('ERC20AssetDelist', (_message.Message,), {
  'DESCRIPTOR' : _ERC20ASSETDELIST,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20AssetDelist)
  })
_sym_db.RegisterMessage(ERC20AssetDelist)

ERC20Deposit = _reflection.GeneratedProtocolMessageType('ERC20Deposit', (_message.Message,), {
  'DESCRIPTOR' : _ERC20DEPOSIT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20Deposit)
  })
_sym_db.RegisterMessage(ERC20Deposit)

ERC20Withdrawal = _reflection.GeneratedProtocolMessageType('ERC20Withdrawal', (_message.Message,), {
  'DESCRIPTOR' : _ERC20WITHDRAWAL,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20Withdrawal)
  })
_sym_db.RegisterMessage(ERC20Withdrawal)

ERC20Event = _reflection.GeneratedProtocolMessageType('ERC20Event', (_message.Message,), {
  'DESCRIPTOR' : _ERC20EVENT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20Event)
  })
_sym_db.RegisterMessage(ERC20Event)

BTCDeposit = _reflection.GeneratedProtocolMessageType('BTCDeposit', (_message.Message,), {
  'DESCRIPTOR' : _BTCDEPOSIT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BTCDeposit)
  })
_sym_db.RegisterMessage(BTCDeposit)

BTCWithdrawal = _reflection.GeneratedProtocolMessageType('BTCWithdrawal', (_message.Message,), {
  'DESCRIPTOR' : _BTCWITHDRAWAL,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BTCWithdrawal)
  })
_sym_db.RegisterMessage(BTCWithdrawal)

BTCEvent = _reflection.GeneratedProtocolMessageType('BTCEvent', (_message.Message,), {
  'DESCRIPTOR' : _BTCEVENT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BTCEvent)
  })
_sym_db.RegisterMessage(BTCEvent)

EthereumAddress = _reflection.GeneratedProtocolMessageType('EthereumAddress', (_message.Message,), {
  'DESCRIPTOR' : _ETHEREUMADDRESS,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.EthereumAddress)
  })
_sym_db.RegisterMessage(EthereumAddress)

BitcoinAddress = _reflection.GeneratedProtocolMessageType('BitcoinAddress', (_message.Message,), {
  'DESCRIPTOR' : _BITCOINADDRESS,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BitcoinAddress)
  })
_sym_db.RegisterMessage(BitcoinAddress)

Identifier = _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFIER,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.Identifier)
  })
_sym_db.RegisterMessage(Identifier)

AddValidator = _reflection.GeneratedProtocolMessageType('AddValidator', (_message.Message,), {
  'DESCRIPTOR' : _ADDVALIDATOR,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.AddValidator)
  })
_sym_db.RegisterMessage(AddValidator)

RemoveValidator = _reflection.GeneratedProtocolMessageType('RemoveValidator', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEVALIDATOR,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.RemoveValidator)
  })
_sym_db.RegisterMessage(RemoveValidator)

ValidatorEvent = _reflection.GeneratedProtocolMessageType('ValidatorEvent', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATOREVENT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ValidatorEvent)
  })
_sym_db.RegisterMessage(ValidatorEvent)

ChainEvent = _reflection.GeneratedProtocolMessageType('ChainEvent', (_message.Message,), {
  'DESCRIPTOR' : _CHAINEVENT,
  '__module__' : 'proto.chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ChainEvent)
  })
_sym_db.RegisterMessage(ChainEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import base64
import random
import string
from typing import Dict, List

from .fixtures import walletclient, walletname, walletpassphrase  # noqa: F401


def random_metadata() -> List[Dict[str, str]]:
    return [
        {
            "key": "".join(random.choice(string.ascii_uppercase) for i in range(10)),
            "value": "".join(random.choice(string.ascii_lowercase) for i in range(10)),
        }
    ]


def test_walletclient(walletclient, walletname, walletpassphrase):  # noqa: F811
    wname = walletname
    wpass = walletpassphrase

    # Create wallet
    r = walletclient.create(wname, wpass)
    assert r.status_code == 200
    j = r.json()
    assert "token" in j, "Bad response: {}".format(j)

    # Log out
    r = walletclient.logout()
    assert r.status_code == 200
    j = r.json()
    assert "success" in j, "Bad response: {}".format(j)
    assert j["success"] is True

    # Log in
    r = walletclient.login(wname, wpass)
    assert r.status_code == 200
    j = r.json()
    assert "token" in j, "Bad response: {}".format(j)

    # Generate keypair
    meta = random_metadata()
    r = walletclient.generatekey(wpass, meta)
    assert r.status_code == 200
    j = r.json()
    assert "key" in j, "Bad response: {}".format(j)
    k = j["key"]
    assert len(k["pub"]) == 64  # ED25519 pubKey is 32 bytes

    # List keypairs
    r = walletclient.listkeys()
    assert r.status_code == 200
    j = r.json()
    assert "keys" in j, "Bad response: {}".format(j)
    assert len(j["keys"]) == 1

    # Get one keypair
    r = walletclient.getkey(k["pub"])
    assert r.status_code == 200
    j = r.json()
    assert "key" in j, "Bad response: {}".format(j)
    k2 = j["key"]
    assert k2 == k

    # Sign tx
    blob = b"abc123"
    tx = base64.b64encode(blob).decode("ascii")
    r = walletclient.signtx(tx, k["pub"])
    assert r.status_code == 200
    j = r.json()
    assert "signedTx" in j, "Bad response: {}".format(j)
    signedTx = j["signedTx"]
    assert signedTx["pubKey"] == k["pub"]
    assert signedTx["data"] == tx
    # TODO: check signature

    # Update key metadata
    meta2 = random_metadata()
    r = walletclient.updatekeymetadata(k["pub"], wpass, meta2)
    assert r.status_code == 200
    j = r.json()
    assert "success" in j, "Bad response: {}".format(j)
    assert j["success"] is True

    # Get one keypair, again
    r = walletclient.getkey(k["pub"])
    assert r.status_code == 200
    j = r.json()
    assert "key" in j, "Bad response: {}".format(j)
    k3 = j["key"]
    assert k3["meta"] == meta2

    # Taint key
    r = walletclient.taintkey(k["pub"], wpass)
    assert r.status_code == 200, "Bad response: {}".format(r.text)
    j = r.json()
    assert "success" in j, "Bad response: {}".format(j)
    assert j["success"] is True



import base64
import binascii
from google.protobuf.empty_pb2 import Empty

import vegaapiclient as vac

from .fixtures import (  # noqa: F401
    trading,
    tradingdata,
    walletclient,
    walletname,
    walletpassphrase,
    walletClientWalletKeypair,
)


def test_SubmitOrder(trading, tradingdata, walletClientWalletKeypair):  # noqa: F811
    (
        walletclient,
        walletname,
        passphrase,
        pubKey,  # noqa: F811
    ) = walletClientWalletKeypair

    # Get free money for the pubKey
    request = vac.api.trading.NotifyTraderAccountRequest(
        notif=vac.vega.NotifyTraderAccount(traderID=pubKey, amount=10000000)
    )
    response = trading.NotifyTraderAccount(request)
    assert response.submitted

    markets = tradingdata.Markets(Empty()).markets
    assert len(markets) > 0
    market = markets[0]

    # Prepare the SubmitOrder
    now = int(tradingdata.GetVegaTime(Empty()).timestamp)
    request = vac.api.trading.SubmitOrderRequest(
        submission=vac.vega.OrderSubmission(
            expiresAt=now + 120000000000,
            marketID=market.id,
            partyID=pubKey,
            price=10,
            side=vac.vega.Side.SIDE_BUY,
            size=1,
            timeInForce=vac.vega.Order.TimeInForce.TIF_GTT,
            type=vac.vega.Order.Type.TYPE_LIMIT,
        )
    )
    response = trading.PrepareSubmitOrder(request)
    blob = response.blob

    # Sign the tx
    r = walletclient.signtx(base64.b64encode(blob).decode("ascii"), pubKey)
    assert r.status_code == 200
    signedTx = r.json()["signedTx"]

    # Submit the signed transaction
    assert blob == base64.b64decode(signedTx["data"])
    request = vac.api.trading.SubmitTransactionRequest(
        tx=vac.vega.SignedBundle(
            data=blob,
            sig=base64.b64decode(signedTx["sig"]),
            pubKey=binascii.unhexlify(signedTx["pubKey"]),
        )
    )
    assert len(request.tx.pubKey) == 32, binascii.hexlify(request.tx.pubKey)
    response = trading.SubmitTransaction(request)
    assert response.success
